import java.awt.*;
import javax.swing.event.MouseInputAdapter;
import java.awt.event.MouseEvent;

/**
 * MyCanvas: an example subclass of Canvas.
 * In this version, the Canvas creates another object to listen for mouse events.
 * Note that MouseInputAdapter is a predefined class that implements MouseListener
 * (among other things) with a bunch of methods that do nothing; it allows us to
 * simply and easily override only the methods we're interested in.
 * Note that this version BEHAVES exactly the same as version 22, it's just
 * organized differently.
 * 
 * @author Stephen Bloch
 * @version 22, Feb 15 2005
 * @since version 19
 */
public class MyCanvas extends Canvas
{
    private String currentString;
    private int boxX = 20, boxY = 10;
    /**
     * Constructor for objects of class MyCanvas
     */
    public MyCanvas()
    {
        this.setSize (200, 300); // default is (0,0), i.e. invisible
        this.currentString = "hello";
        this.addMouseListener (new MouseInputAdapter () {
                public void mouseClicked (MouseEvent evt) {
                    boxX = evt.getX();
                    boxY = evt.getY();
                    repaint();
                }});
    }

    /**
     * @see java.awt.Canvas.paint()
     */
    public void paint (Graphics g) {
        // In Java 1.2 and above, the Graphics object is really a Graphics2D object,
        // which allows you to do more cool stuff.  So we'll convert it.
        Graphics2D g2 = (Graphics2D)g;
        
        g2.draw (new Rectangle (this.boxX, this.boxY, 30, 20));
        
        g2.setPaint (Color.blue);
        g2.drawString (this.currentString, 5, 15);
        
        int[] xpoints = { 50, 100, 100, 70, 62 };
        int[] ypoints = { 100, 70, 145, 140, 70 };
        Polygon shape = new Polygon (xpoints, ypoints, 5);
        
        g2.setPaint (Color.magenta);
        g2.fill (shape);
    }

    /**
     * set the String currently being displayed in the Canvas.
     * @param newString the new String to display.
     * @since version 20
     */
    public void setCurrentString (String newString) {
        this.currentString = newString;
        this.repaint();
        // If you leave this out, system doesn't know that anything
        // has changed, so it doesn't bother calling paint().
    }

}